| Astrand | R Documentation |
In an interesting early study on changes in 'working capacity' with sex and age, Astrand (1952) recorded measurements of a variety of physiological parameters in subjects who undertook exercise at maximal intensity.
Astrand, Per-Olof. Experimental studies of physical working capacity in relation to sex and age. Munksgaard Forlag.
## Not run:
plot(Heart_rate ~ Age, data = Astrand)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.