| Loch_Leven | R Documentation |
Loch Leven is situated in lowland Scotland in the Perth and Kinross area. It is the largest shallow lake in Great Britain with an area of 13.3km$^2$, mean depth 3.9m and a maximum depth 25.5m. Regular monitoring is carried out by the *Centre for Ecology & Hydrology* in Edinburgh.
One of the features of interest is the water quality and hence the relationship between *chlorophyll$_a$* (as an indicator of water quality) and *soluble reactive phosphorus* (a nutrient) is very important. The monthly means for chlorophyll$_a$ ('lchla') and soluble reactive phosphorus ('srp') are provided from January 1988 to December 2007, along with the 'year' and 'month' of each measurement.
The Loch_Leven dataframe consists of four variables:
year: the year of the measurement;
month: the month of the measurement, as an integer (1-12);
chla: the measurement of chlorophyll$_a$;
srp: the measurement of soluble reactive phosphorus.
Ferguson, C.A., Bowman, A.W., Scott, E.M., Carvalho, L. (2009). Multivariate varying-coefficient models for an ecological system. Environmetrics 20.4, 460-476.
## Not run:
with(Loch_Leven, plot(year, log(chla)))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.