| Scottish_referendum | R Documentation |
These data record the results of the Scottish referendum on independence held in 2014. The variables include the votes counted in each local council area along with other social characteristics.
Scottish Independence Referendum 2014: Analysis of results. Research Paper 14/50, 30 September 2014. https://commonslibrary.parliament.uk/research-briefings/rp14-50/
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.