| flour_beetles | R Documentation |
The 'confused flour beetle' Tribolium confusum can infest stored flour and grain. These data on the numbers of beetles killed by exposure to different concentrations of multiple toxins. The data were reported in an early paper by Strand (1930) on how to measure the toxicity of compounds. The trials of some compounds were replicated. Toxin concentration is measured in mg/l.
Strand, A.L. (1930). Measuring the toxicity of insect fumigants. Industrial & Engineering Chemistry Analytical Edition, 2, 4-8.
## Not run:
hacid <- subset(flour_beetles, Toxin == "Hydrocyanic_acid")
plot(Dead / (Living + Dead) ~ Concentration, data = hacid)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.