rp.colours: Specify the colours to be used in some 'rpanel' functions.

View source: R/rp_colours.R

rp.coloursR Documentation

Specify the colours to be used in some rpanel functions.

Description

Returns a named vector specifying the colours to be used in some rpanel functions. Where colours for particular purposes are not specified default values are returned.

Usage

rp.colours(cols)

Arguments

cols

a named vector of colours.

Details

Some rpanel functions have a cols argument which can be used to specify the colours used when creating some aspects of the resulting visual display. The rp.colours function is used internally to set these colours, altered where appropriate by the elements of cols. Users need not employ this function, except to view the default colours.

Value

A named vector of the colours.

Examples

## Not run: 
# View the defauklt colours.
rp.colours()

# Alter particular colours
model <- lm(Giving ~ Attend + Employ, data = CofE)
rp.coefficients(model)
rp.coefficients(model, cols = c('estimate' = 'darkgreen'))

## End(Not run)

rpanel documentation built on March 12, 2026, 9:07 a.m.

Related to rp.colours in rpanel...