| rp.tables | R Documentation |
This function launches a panel which allows standard normal, t, chi-squared and F distributions to be plotted, with interactive control of parameters, tail probability and p-value calculations.
rp.tables(panel = TRUE, panel.plot = TRUE,
hscale = NA, vscale = hscale,
distribution = "normal", degf1 = 5, degf2 = 30,
observed.value = " ",
observed.value.showing = !is.na(observed.value),
probability = 0.05, tail.probability, tail.direction, heading)
panel |
a logical value determining whether an interactive panel is created or a static plot is produced. |
panel.plot |
a logical parameter, relevant to the |
hscale, vscale |
horizontal and vertical scaling factors, relevant to the |
distribution |
a character string which determines which distribution is to be plotted. Current options are "normal" (default), "t", "chi-squared" and "F". |
degf1, degf2 |
The degrees of freedom used for the chi-squared ( |
observed.value |
a numerical value, or a character string which will be converted by |
observed.value.showing |
a logical value which determines whether the observed value (if any) is displayed on the plot. |
probability |
the value of the tail probability used when tail area is shaded. |
tail.probability |
a character string which determines whether the tail area is drawn from the observed value ( |
tail.direction |
a character string which determines whether the lower ( |
heading |
a character string which will appear as a heading of the plot. If this is missing, a heading based on the selected distribution will be created. |
The panel contains radiobuttons to select the standard normal, t, chi-squared or F distributions. Doublebuttons are available to control the degrees of freedom. An observed value can be added to the plot, with optional determination of the corresponding p-value. Alternatively, shaded areas corresponding to tail probabilities of specified value can be displayed.
The tcltk panel object is returned.
rpanel: Simple interactive controls for R functions using the tcltk package. Journal of Statistical Software, 17, issue 9.
## Not run:
rp.tables()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.