The management of objects within the rpanel environment is usually handled `behind the scenes' but it can occasionally be useful to retrieve an object there explicitly.
rp.var.get(panelname, name)
the panelname of the relevant panel. This is usually identified as panel$panelname. If this argument is set to NULL then the object is not retrieved from a panel.
the name of the variable in character form.
rpanel: Simple interactive controls for R functions using the tcltk package. Journal of Statistical Software, 17, issue 9.
rp.var.get