rp.wrangle: Collate and organise specific datasets

View source: R/rp_wrangle.R

rp.wrangleR Documentation

Collate and organise specific datasets

Description

Specific datasets are read and reorganised into a convenient form for analysis.

Usage

  rp.wrangle(name)
  

Arguments

name

a single character string giving the name of the dataset required.

Details

Calling the function with no arguments, as rp.wrangle(), will print the names of the datasets available.

The readxl, readr and dplyr packages are used for some datasets.

Value

The dataset required, returned as a dataframe or tibble. If the function is called with no arguments, the dataset names are returned in a dataframe along with appropriate comments.

Examples

## Not run: 
  rp.wrangle()
  rp.wrangle("cofe_2019")

## End(Not run)

rpanel documentation built on March 12, 2026, 9:07 a.m.

Related to rp.wrangle in rpanel...