| rpanel-package | R Documentation |
rpanel provides a set of functions to build simple GUI controls for R functions. Uses include changing a parameter on a graph (and animating it) with a slider, or a "doublebutton", up to more sophisticated mini-applications. In addition to functions which create controls, a number of ‘cartoon’ functions built on these controls are also available.
This package contains a number of functions (with help and examples) and several example scripts.
Cartoon functions:
rp.ci: Confidence intervals
rp.coefficients: Visualisation of the effects of the coefficients in a linear model or glm
rp.contingency: Visualisation of two-way contingency tables with uncertainties
rp.drop1: Visualisation of the results of dropping all single terms from a model
rp.firth: Sampling in a firth
rp.geosim: Simulation of spatial processes
rp.gulls: An interactive problem-solving exercise on deciding the sex of a herring gull
rp.likelihood: Exploration of one and two parameter likelihood functions
rp.lm: Visualisation of linear models with one or two explanatory variables
rp.logistic: Interactive display of logistic regression with a single covariate
rp.mururoa: Sampling in Mururoa Atoll
rp.normal: Fitting a normal distribution to a single sample
rp.plot3d: Interactive display of a plot of three variables
rp.plot4d: Interactive display of a plot of four variables
rp.power: Power calculations for a two-sample t-test
rp.rmplot: Plotting of repeated measurement data
rp.sample: Interactive exploration of sampling variation
rp.surface: Displaying the uncertainty in an estimate of a surface
rp.t_test: Visualisation for inference in comparing the means of one or two samples
rp.tables: Interactive statistical tables
rp.spacetime: A version of rp.plot4d designed for space-time data
Functions to create individual controls:
rp.control: create an rpanel
rp.slider: add a slider to a panel, to graphically control a numeric variable
rp.textentry: adds a box allows text to be entered
rp.button: adds a button to the panel with a nominated function called on pressing
rp.checkbox: adds a checkbox to the panel, to control a logical variable
rp.radiogroup: adds a set of radiobuttons to the panel
rp.listbox: adds a listbox to the panel
rp.combo: adds a combo box to the panel
rp.doublebutton: adds a widget with '+' and '-' buttons, to increment and decrement a variable
rp.menu: adds a menu to the panel
rp.text: adds a text box to the panel
rp.image: adds an image to the panel; the action function is called with coordinates on clicking
rp.line: draws a line connecting the pixel locations x1, y1 to x2, y2 on the specified rp.image
rp.deleteline: removes a line from an rp.image
rp.clearlines: removes all lines from an rp.image
rp.messagebox: displays a message in a pop-up window
rp.tkrplot: allows R graphics to be displayed in a panel
rp.tkrreplot: allows R graphics to be refreshed in a panel.
rp.timer: executes an action function repeatedly until a condition is satisfied
rp.block: blocks use of the R console until a panel is closed
rp.panel: returns a named panel or the most recently created panel
rp.var.put: place an object into the rpanel environment, usually within a panel
rp.var.get: retrieve an object from the rpanel environment, usually from a panel
rp.pos: a demonstration function for layout control
rp.grid: a grid system for layout control
rp.do: executes a nominated user defined callback function
rp.colour.key: a colour key to associate with a plot
Generally speaking these functions have a parameter, name, which is used to later delete or modify a widget.
E. Crawford & A. Bowman
Maintainer: Adrian Bowman <adrian.bowman@glasgow.ac.uk>
rpanel: Simple interactive controls for R functions using the tcltk package. Journal of Statistical Software, 17, issue 9.
rp.control,rp.button,rp.slider,rp.doublebutton,rp.textentry,rp.checkbox,rp.radiogroup
## Not run:
rp.gulls()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.