| mammal_speed | R Documentation |
In an investigation of the relationship between mass (kg) and maximal running speed (km/hr) in terrestrial mammals, Garland (1983) collected information from published articles on these two variables for a large number of different species. The measurements are not all recorded to the same level of accuracy since the results have been collated from the work of a number of different scientists.
The mammal_speed dataframe consists of four columns of data:
Name: the name of the mammal;
Family: the family of the mammal;
Mass: the characteristic mass of the mammal in kg;
Speed: the characteristic maximal running speed of the mammal in km/hr.
The rodent dataset in the rpanel package is a subset of these data.
Garland, T. (1983). The relation between maximal running speed and body mass in terrestrial animals. Journal of the Zoological Society of London, 199, 155-170.
## Not run:
if (require(ggplot2, quietly = TRUE)) {
ggplot(mammal_speed, aes(log(Mass), log(Speed), col = Family)) + geom_point()
}
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.