| rp.colours | R Documentation |
Returns a named vector specifying the colours to be used in some rpanel functions. Where colours for particular purposes are not specified default values are returned.
rp.colours(cols)
cols |
a named vector of colours. |
Some rpanel functions have a cols argument which can be used to specify the colours used when creating some aspects of the resulting visual display. The rp.colours function is used internally to set these colours, altered where appropriate by the elements of cols. Users need not employ this function, except to view the default colours.
A named vector of the colours.
## Not run:
# View the defauklt colours.
rp.colours()
# Alter particular colours
model <- lm(Giving ~ Attend + Employ, data = CofE)
rp.coefficients(model)
rp.coefficients(model, cols = c('estimate' = 'darkgreen'))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.