| rp.drop1 | R Documentation |
Plot the results, in terms of F-tests, of dropping all individual terms from a linear model. This is essentially a graphical display of the results from the function drop1. The hierarchy of the model formula is respected so that when interaction terms are present main effect terms are not considered.
rp.drop1(model, subset.terms, p.reference = c(0.05, 0.01), cols)
model |
a linear model produced by the |
subset.terms |
a character vector containing the names of the subset of terms to be examined. |
p.reference |
a numeric vector specifying the p-values for which the positions on the F-value scale will be marked. |
cols |
a named vector of colours to be used in the construction of the plot. See |
The rp.colours function is used internally to set these colours, altered where appropriate by the elements of cols. Users need not employ this function, except to view the default colours.
The ggplot2 package is required by this function. If the ggforce is available, this is used to scale the heights of facet rows when there are multiple terms with different degrees of freedom.
A ggplot object containing the plot.
## Not run:
model <- lm(Giving ~ Attend + Employ, data = CofE)
rp.drop1(model)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.