| rp.wrangle | R Documentation |
Specific datasets are read and reorganised into a convenient form for analysis.
rp.wrangle(name)
name |
a single character string giving the name of the dataset required. |
Calling the function with no arguments, as rp.wrangle(), will print the names of the datasets available.
The readxl, readr and dplyr packages are used for some datasets.
The dataset required, returned as a dataframe or tibble. If the function is called with no arguments, the dataset names are returned in a dataframe along with appropriate comments.
## Not run:
rp.wrangle()
rp.wrangle("cofe_2019")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.